@@ -1,16 +1,23 @@
 from importlib.metadata import version
 
-from kreuzberg._config import discover_and_load_config, load_config_from_path, try_discover_config
-from kreuzberg._entity_extraction import SpacyEntityExtractionConfig
-from kreuzberg._gmft import GMFTConfig
-from kreuzberg._language_detection import LanguageDetectionConfig
-from kreuzberg._ocr._easyocr import EasyOCRConfig
-from kreuzberg._ocr._paddleocr import PaddleOCRConfig
-from kreuzberg._ocr._tesseract import TesseractConfig
-
-from ._ocr._tesseract import PSMMode
 from ._registry import ExtractorRegistry
-from ._types import Entity, ExtractionConfig, ExtractionResult, Metadata, TableData
+from ._types import (
+    EasyOCRConfig,
+    Entity,
+    ExtractedImage,
+    ExtractionConfig,
+    ExtractionResult,
+    GMFTConfig,
+    ImageOCRConfig,
+    ImageOCRResult,
+    LanguageDetectionConfig,
+    Metadata,
+    PaddleOCRConfig,
+    PSMMode,
+    SpacyEntityExtractionConfig,
+    TableData,
+    TesseractConfig,
+)
 from .exceptions import KreuzbergError, MissingDependencyError, OCRError, ParsingError, ValidationError
 from .extraction import (
     batch_extract_bytes,
@@ -28,10 +35,13 @@ __version__ = version("kreuzberg")
 __all__ = [
     "EasyOCRConfig",
     "Entity",
+    "ExtractedImage",
     "ExtractionConfig",
     "ExtractionResult",
     "ExtractorRegistry",
     "GMFTConfig",
+    "ImageOCRConfig",
+    "ImageOCRResult",
     "KreuzbergError",
     "LanguageDetectionConfig",
     "Metadata",
@@ -49,11 +59,8 @@ __all__ = [
     "batch_extract_bytes_sync",
     "batch_extract_file",
     "batch_extract_file_sync",
-    "discover_and_load_config",
     "extract_bytes",
     "extract_bytes_sync",
     "extract_file",
     "extract_file_sync",
-    "load_config_from_path",
-    "try_discover_config",
 ]
