@@ -1,9 +1,11 @@
 from __future__ import annotations
 
-import contextlib
+import logging
 import re
+import subprocess
 import sys
-from json import JSONDecodeError, loads
+from itertools import chain
+from json import loads
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, ClassVar, Final, Literal, cast
 
@@ -13,10 +15,10 @@ from anyio import run_process
 from kreuzberg._constants import MINIMAL_SUPPORTED_PANDOC_VERSION
 from kreuzberg._extractors._base import Extractor
 from kreuzberg._mime_types import MARKDOWN_MIME_TYPE
-from kreuzberg._types import ExtractionResult, Metadata
+from kreuzberg._types import ExtractedImage, ExtractionResult, ImageOCRResult, Metadata
 from kreuzberg._utils._string import normalize_spaces
-from kreuzberg._utils._sync import run_taskgroup
-from kreuzberg._utils._tmp import create_temp_file
+from kreuzberg._utils._sync import run_maybe_async, run_taskgroup
+from kreuzberg._utils._tmp import temporary_directory, temporary_file, temporary_file_sync
 from kreuzberg.exceptions import MissingDependencyError, ParsingError, ValidationError
 
 if TYPE_CHECKING:  # pragma: no cover
@@ -81,8 +83,6 @@ NodeType = Literal[
 
 
 class PandocExtractor(Extractor):
-    """Extractor for documents supported by Pandoc."""
-
     _checked_version: bool = False
 
     MIMETYPE_TO_PANDOC_TYPE_MAPPING: ClassVar[Mapping[str, str]] = {
@@ -150,35 +150,11 @@ class PandocExtractor(Extractor):
     }
 
     async def extract_bytes_async(self, content: bytes) -> ExtractionResult:
-        """Extract text and metadata from bytes content using Pandoc.
-
-        Args:
-            content: The content bytes to process.
-
-        Returns:
-            ExtractionResult with the extracted text and metadata.
-        """
         extension = self._get_pandoc_type_from_mime_type(self.mime_type)
-        input_file, unlink = await create_temp_file(f".{extension}")
-
-        try:
-            await AsyncPath(input_file).write_bytes(content)
+        async with temporary_file(f".{extension}", content) as input_file:
             return await self.extract_path_async(input_file)
-        finally:
-            await unlink()
 
     async def extract_path_async(self, path: Path) -> ExtractionResult:
-        """Extract text and metadata from a file using Pandoc.
-
-        Args:
-            path: The path to the file to process.
-
-        Raises:
-            ParsingError: If the file data could not be extracted.
-
-        Returns:
-            ExtractionResult with the extracted text and metadata.
-        """
         await self._validate_pandoc_version()
         self._get_pandoc_type_from_mime_type(self.mime_type)
 
@@ -188,49 +164,27 @@ class PandocExtractor(Extractor):
             results = await run_taskgroup(metadata_task, content_task)
             metadata, content = cast("tuple[Metadata, str]", results)
 
-            return ExtractionResult(
-                content=normalize_spaces(content), metadata=metadata, mime_type=MARKDOWN_MIME_TYPE, chunks=[]
+            result = ExtractionResult(
+                content=normalize_spaces(content), metadata=metadata, mime_type=MARKDOWN_MIME_TYPE
             )
+
+            if self.config.extract_images:
+                images = await self._extract_images_with_pandoc(str(path))
+                result.images = images
+                if self.config.ocr_extracted_images and result.images:
+                    image_ocr_results = await self._process_images_with_ocr(result.images)
+                    result.image_ocr_results = image_ocr_results
+
+            return result
         except ExceptionGroup as eg:
             raise ParsingError("Failed to process file", context={"file": str(path), "errors": eg.exceptions}) from eg
 
     def extract_bytes_sync(self, content: bytes) -> ExtractionResult:
-        """Pure sync implementation of extract_bytes.
-
-        Args:
-            content: The content bytes to process.
-
-        Returns:
-            ExtractionResult with the extracted text and metadata.
-        """
-        import os
-        import tempfile
-        from pathlib import Path
-
         extension = self._get_pandoc_type_from_mime_type(self.mime_type)
-        fd, temp_path = tempfile.mkstemp(suffix=f".{extension}")
-
-        try:
-            with os.fdopen(fd, "wb") as f:
-                f.write(content)
-
-            return self.extract_path_sync(Path(temp_path))
-        finally:
-            with contextlib.suppress(OSError):
-                Path(temp_path).unlink()
+        with temporary_file_sync(f".{extension}", content) as temp_path:
+            return self.extract_path_sync(temp_path)
 
     def extract_path_sync(self, path: Path) -> ExtractionResult:
-        """Pure sync implementation of extract_path.
-
-        Args:
-            path: The path to the file to process.
-
-        Returns:
-            ExtractionResult with the extracted text and metadata.
-
-        Raises:
-            ParsingError: When file processing fails.
-        """
         self._validate_pandoc_version_sync()
         self._get_pandoc_type_from_mime_type(self.mime_type)
 
@@ -238,25 +192,31 @@ class PandocExtractor(Extractor):
             metadata = self._extract_metadata_sync(path)
             content = self._extract_file_sync(path)
 
-            return ExtractionResult(
-                content=normalize_spaces(content), metadata=metadata, mime_type=MARKDOWN_MIME_TYPE, chunks=[]
+            result = ExtractionResult(
+                content=normalize_spaces(content), metadata=metadata, mime_type=MARKDOWN_MIME_TYPE
             )
+
+            if self.config.extract_images:
+                images: list[ExtractedImage] = run_maybe_async(self._extract_images_with_pandoc, str(path))
+                result.images = images
+                if self.config.ocr_extracted_images and result.images:
+                    image_ocr_results: list[ImageOCRResult] = run_maybe_async(
+                        self._process_images_with_ocr, result.images
+                    )
+                    result.image_ocr_results = image_ocr_results
+
+            return result
         except Exception as e:
             raise ParsingError("Failed to process file", context={"file": str(path), "error": str(e)}) from e
 
     async def _validate_pandoc_version(self) -> None:
-        """Validate that the installed Pandoc version meets the minimum requirement.
-
-        Raises:
-            MissingDependencyError: If Pandoc is not installed or version is too low
-        """
         try:
             if self._checked_version:
                 return
 
             command = ["pandoc", "--version"]
             result = await run_process(command)
-            stdout = result.stdout.decode()
+            stdout = result.stdout.decode("utf-8")
 
             version_match = re.search(
                 r"pandoc(?:\.exe)?(?:\s+|\s+v|\s+version\s+)(\d+)\.(\d+)(?:\.(\d+))?", stdout, re.IGNORECASE
@@ -300,14 +260,6 @@ class PandocExtractor(Extractor):
 
     @staticmethod
     def _get_pandoc_key(key: str) -> str | None:
-        """Map Pandoc metadata keys to our standard metadata keys.
-
-        Args:
-            key: The key from Pandoc metadata
-
-        Returns:
-            The mapped key name for our system, or None if not mapped
-        """
         if key == "abstract":
             return "summary"
 
@@ -326,17 +278,6 @@ class PandocExtractor(Extractor):
         return key
 
     def _get_pandoc_type_from_mime_type(self, mime_type: str) -> str:
-        """Get Pandoc format type from MIME type.
-
-        Args:
-            mime_type: The MIME type to look up
-
-        Returns:
-            The corresponding Pandoc type
-
-        Raises:
-            ValidationError: If mime_type is not supported
-        """
         if pandoc_type := (self.MIMETYPE_TO_PANDOC_TYPE_MAPPING.get(mime_type, "")):
             return pandoc_type
 
@@ -350,20 +291,8 @@ class PandocExtractor(Extractor):
         raise ValidationError(f"Unsupported mime type: {mime_type}")
 
     async def _handle_extract_metadata(self, input_file: str | PathLike[str]) -> Metadata:
-        """Extract metadata from a file using Pandoc.
-
-        Args:
-            input_file: The file to extract metadata from
-
-        Returns:
-            The extracted metadata
-
-        Raises:
-            ParsingError: If metadata extraction fails
-        """
         pandoc_type = self._get_pandoc_type_from_mime_type(self.mime_type)
-        metadata_file, unlink = await create_temp_file(".json")
-        try:
+        async with temporary_file(".json") as metadata_file:
             command = [
                 "pandoc",
                 str(input_file),
@@ -384,26 +313,10 @@ class PandocExtractor(Extractor):
 
             json_data = loads(await AsyncPath(metadata_file).read_text("utf-8"))
             return self._extract_metadata(json_data)
-        except (RuntimeError, OSError, JSONDecodeError) as e:
-            raise ParsingError("Failed to extract file data", context={"file": str(input_file)}) from e
-        finally:
-            await unlink()
 
     async def _handle_extract_file(self, input_file: str | PathLike[str]) -> str:
-        """Extract text content from a file using Pandoc.
-
-        Args:
-            input_file: The file to extract content from
-
-        Returns:
-            The extracted text content
-
-        Raises:
-            ParsingError: If content extraction fails
-        """
         pandoc_type = self._get_pandoc_type_from_mime_type(self.mime_type)
-        output_path, unlink = await create_temp_file(".md")
-        try:
+        async with temporary_file(".md") as output_path:
             command = [
                 "pandoc",
                 str(input_file),
@@ -426,20 +339,8 @@ class PandocExtractor(Extractor):
             text = await AsyncPath(output_path).read_text("utf-8")
 
             return normalize_spaces(text)
-        except (RuntimeError, OSError) as e:
-            raise ParsingError("Failed to extract file data", context={"file": str(input_file)}) from e
-        finally:
-            await unlink()
 
     def _extract_metadata(self, raw_meta: dict[str, Any]) -> Metadata:
-        """Extract structured metadata from Pandoc JSON metadata.
-
-        Args:
-            raw_meta: The raw metadata from Pandoc
-
-        Returns:
-            Structured metadata
-        """
         meta: Metadata = {}
 
         if (
@@ -467,15 +368,17 @@ class PandocExtractor(Extractor):
 
             extracted = self._extract_meta_value(value)
             if extracted:
-                if pandoc_key in ("languages", "authors"):
-                    extracted = [extracted]  # type: ignore[list-item]
+                if pandoc_key in ("languages", "authors") and not isinstance(extracted, list):
+                    extracted = [extracted]
                 meta[pandoc_key] = extracted  # type: ignore[literal-required]
 
         citations_from_blocks = [
             cite["citationId"]
-            for block in raw_meta.get("blocks", [])
-            if block.get(TYPE_FIELD) == "Cite"
-            for cite in block.get(CONTENT_FIELD, [[{}]])[0]
+            for cite in chain.from_iterable(
+                block.get(CONTENT_FIELD, [[{}]])[0]
+                for block in raw_meta.get("blocks", [])
+                if block.get(TYPE_FIELD) == "Cite"
+            )
             if isinstance(cite, dict)
         ]
         if citations_from_blocks and "citations" not in meta:
@@ -486,49 +389,22 @@ class PandocExtractor(Extractor):
         return meta
 
     def _extract_inline_text(self, node: dict[str, Any], type_field: str = "t", content_field: str = "c") -> str | None:
-        """Extract text from an inline node in a document structure.
-
-        Args:
-            node: The node to extract text from
-            type_field: The field name for the node type
-            content_field: The field name for the node content
-
-        Returns:
-            The extracted text or None if no text could be extracted
-        """
-        if node_type := node.get(type_field):
-            if node_type == "Str":
+        match node.get(type_field):
+            case "Str":
                 return node.get(content_field)
-            if node_type == "Space":
+            case "Space":
                 return " "
-            if node_type in ("Emph", "Strong"):
+            case "Emph" | "Strong":
                 return self._extract_inlines(node.get(content_field, []))
-        return None
+            case _:
+                return None
 
     def _extract_inlines(self, nodes: list[dict[str, Any]]) -> str | None:
-        """Extract text from a list of inline nodes.
-
-        Args:
-            nodes: The list of nodes to extract text from
-
-        Returns:
-            The extracted text or None if no text could be extracted
-        """
         texts = [text for node in nodes if (text := self._extract_inline_text(node))]
         result = "".join(texts).strip()
         return result if result else None
 
     def _extract_meta_value(self, node: Any, type_field: str = "t", content_field: str = "c") -> str | list[str] | None:
-        """Extract a metadata value from a node.
-
-        Args:
-            node: The node to extract metadata from
-            type_field: The field name for the node type
-            content_field: The field name for the node content
-
-        Returns:
-            The extracted metadata value or None if no metadata could be extracted
-        """
         if not isinstance(node, dict) or type_field not in node:
             return None
 
@@ -554,13 +430,8 @@ class PandocExtractor(Extractor):
                 return self._extract_inlines(content)
 
             if node_type == "MetaList":
-                results = []
-                for value in [value for item in content if (value := self._extract_meta_value(item))]:
-                    if isinstance(value, list):
-                        results.extend(value)
-                    else:
-                        results.append(value)
-                return results
+                values = [value for item in content if (value := self._extract_meta_value(item))]
+                return list(chain.from_iterable(value if isinstance(value, list) else [value] for value in values))
 
             if node_type == "MetaBlocks" and (
                 blocks := [block for block in content if block.get(type_field) == "Para"]
@@ -578,14 +449,17 @@ class PandocExtractor(Extractor):
         return None
 
     def _validate_pandoc_version_sync(self) -> None:
-        """Synchronous version of _validate_pandoc_version."""
-        import subprocess
-
         try:
             if self._checked_version:
                 return
 
-            result = subprocess.run(["pandoc", "--version"], capture_output=True, text=True, check=False)  # noqa: S607
+            result = subprocess.run(
+                ["pandoc", "--version"],  # noqa: S607
+                capture_output=True,
+                text=True,
+                check=False,
+                encoding="utf-8",
+            )
 
             if result.returncode != 0:
                 raise MissingDependencyError(
@@ -624,16 +498,9 @@ class PandocExtractor(Extractor):
             ) from e
 
     def _extract_metadata_sync(self, path: Path) -> Metadata:
-        """Synchronous version of _handle_extract_metadata."""
-        import os
-        import subprocess
-        import tempfile
-
         pandoc_type = self._get_pandoc_type_from_mime_type(self.mime_type)
-        fd, metadata_file = tempfile.mkstemp(suffix=".json")
-        os.close(fd)
 
-        try:
+        with temporary_file_sync(".json") as metadata_file:
             command = [
                 "pandoc",
                 str(path),
@@ -645,33 +512,20 @@ class PandocExtractor(Extractor):
                 str(metadata_file),
             ]
 
-            result = subprocess.run(command, capture_output=True, text=True, check=False)
+            result = subprocess.run(command, capture_output=True, text=True, check=False, encoding="utf-8")
 
             if result.returncode != 0:
                 raise ParsingError("Failed to extract file data", context={"file": str(path), "error": result.stderr})
 
-            with Path(metadata_file).open(encoding="utf-8") as f:
+            with metadata_file.open(encoding="utf-8") as f:
                 json_data = loads(f.read())
 
             return self._extract_metadata(json_data)
 
-        except (OSError, JSONDecodeError) as e:
-            raise ParsingError("Failed to extract file data", context={"file": str(path)}) from e
-        finally:
-            with contextlib.suppress(OSError):
-                Path(metadata_file).unlink()
-
     def _extract_file_sync(self, path: Path) -> str:
-        """Synchronous version of _handle_extract_file."""
-        import os
-        import subprocess
-        import tempfile
-
         pandoc_type = self._get_pandoc_type_from_mime_type(self.mime_type)
-        fd, output_path = tempfile.mkstemp(suffix=".md")
-        os.close(fd)
 
-        try:
+        with temporary_file_sync(".md") as output_path:
             command = [
                 "pandoc",
                 str(path),
@@ -684,26 +538,71 @@ class PandocExtractor(Extractor):
                 str(output_path),
             ]
 
-            result = subprocess.run(command, capture_output=True, text=True, check=False)
+            result = subprocess.run(command, capture_output=True, text=True, check=False, encoding="utf-8")
 
             if result.returncode != 0:
                 raise ParsingError("Failed to extract file data", context={"file": str(path), "error": result.stderr})
 
-            with Path(output_path).open(encoding="utf-8") as f:
+            with output_path.open(encoding="utf-8") as f:
                 text = f.read()
 
             return normalize_spaces(text)
 
-        except OSError as e:
-            raise ParsingError("Failed to extract file data", context={"file": str(path)}) from e
-        finally:
-            with contextlib.suppress(OSError):
-                Path(output_path).unlink()
+    async def _extract_images_with_pandoc(self, file_path: str) -> list[ExtractedImage]:
+        images = []
+
+        with temporary_directory() as temp_dir:
+            media_dir = Path(temp_dir) / "media"
+            media_dir.mkdir()
+
+            try:
+                cmd = [
+                    "pandoc",
+                    str(file_path),
+                    "--extract-media",
+                    str(media_dir),
+                    "-t",
+                    "markdown",
+                    "-o",
+                    "/dev/null",
+                ]
+
+                await run_process(cmd)
+
+                if media_dir.exists():
+                    for img_path in media_dir.rglob("*"):
+                        if img_path.is_file() and img_path.suffix.lower() in {
+                            ".jpg",
+                            ".jpeg",
+                            ".png",
+                            ".gif",
+                            ".bmp",
+                            ".tiff",
+                            ".webp",
+                        }:
+                            try:
+                                image_data = await AsyncPath(img_path).read_bytes()
+
+                                images.append(
+                                    ExtractedImage(
+                                        data=image_data,
+                                        format=img_path.suffix[1:].lower(),
+                                        filename=img_path.name,
+                                        page_number=None,
+                                    )
+                                )
+                            except Exception as e:  # noqa: BLE001
+                                logging.getLogger(__name__).warning(
+                                    "Failed to read extracted image %s: %s", img_path, e
+                                )
+
+            except Exception as e:  # noqa: BLE001
+                logging.getLogger(__name__).warning("Pandoc image extraction failed: %s", e)
+
+        return images
 
 
 class MarkdownExtractor(PandocExtractor):
-    """Extractor for Markdown-based document formats."""
-
     SUPPORTED_MIME_TYPES: ClassVar[set[str]] = {
         "text/x-markdown",
         "text/x-commonmark",
@@ -715,8 +614,6 @@ class MarkdownExtractor(PandocExtractor):
 
 
 class OfficeDocumentExtractor(PandocExtractor):
-    """Extractor for Office document formats (Word, ODT)."""
-
     SUPPORTED_MIME_TYPES: ClassVar[set[str]] = {
         "application/vnd.openxmlformats-officedocument.wordprocessingml.document",
         "application/vnd.oasis.opendocument.text",
@@ -724,8 +621,6 @@ class OfficeDocumentExtractor(PandocExtractor):
 
 
 class EbookExtractor(PandocExtractor):
-    """Extractor for e-book formats (EPUB, FB2)."""
-
     SUPPORTED_MIME_TYPES: ClassVar[set[str]] = {
         "application/epub+zip",
         "application/x-fictionbook+xml",
@@ -733,8 +628,6 @@ class EbookExtractor(PandocExtractor):
 
 
 class StructuredTextExtractor(PandocExtractor):
-    """Extractor for structured text formats (RST, Org, etc.)."""
-
     SUPPORTED_MIME_TYPES: ClassVar[set[str]] = {
         "text/x-rst",
         "text/x-org",
@@ -744,8 +637,6 @@ class StructuredTextExtractor(PandocExtractor):
 
 
 class LaTeXExtractor(PandocExtractor):
-    """Extractor for LaTeX and Typst documents."""
-
     SUPPORTED_MIME_TYPES: ClassVar[set[str]] = {
         "application/x-latex",
         "application/x-typst",
@@ -753,8 +644,6 @@ class LaTeXExtractor(PandocExtractor):
 
 
 class BibliographyExtractor(PandocExtractor):
-    """Extractor for bibliography formats (BibTeX, CSL JSON, etc.)."""
-
     SUPPORTED_MIME_TYPES: ClassVar[set[str]] = {
         "application/x-bibtex",
         "application/x-biblatex",
@@ -765,8 +654,6 @@ class BibliographyExtractor(PandocExtractor):
 
 
 class XMLBasedExtractor(PandocExtractor):
-    """Extractor for XML-based document formats (DocBook, JATS, OPML)."""
-
     SUPPORTED_MIME_TYPES: ClassVar[set[str]] = {
         "application/docbook+xml",
         "application/x-jats+xml",
@@ -775,8 +662,6 @@ class XMLBasedExtractor(PandocExtractor):
 
 
 class TabularDataExtractor(PandocExtractor):
-    """Extractor for tabular data formats (CSV, TSV)."""
-
     SUPPORTED_MIME_TYPES: ClassVar[set[str]] = {
         "text/csv",
         "text/tab-separated-values",
@@ -784,8 +669,6 @@ class TabularDataExtractor(PandocExtractor):
 
 
 class MiscFormatExtractor(PandocExtractor):
-    """Extractor for miscellaneous formats (RTF, man, Jupyter notebooks)."""
-
     SUPPORTED_MIME_TYPES: ClassVar[set[str]] = {
         "application/rtf",
         "text/troff",
