@@ -7,16 +7,17 @@ import queue
 import signal
 import time
 import traceback
-from dataclasses import dataclass, field
 from io import StringIO
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Literal
+from typing import TYPE_CHECKING, Any, cast
 
 import anyio
 import msgspec
+import polars as pl
 from PIL import Image
 
-from kreuzberg._types import TableData
+from kreuzberg._types import GMFTConfig, TableData
+from kreuzberg._utils._cache import get_table_cache
 from kreuzberg._utils._sync import run_sync
 from kreuzberg.exceptions import MissingDependencyError, ParsingError
 
@@ -24,142 +25,68 @@ if TYPE_CHECKING:
     from os import PathLike
 
     from gmft.detectors.base import CroppedTable
-    from pandas import DataFrame
 
 
-@dataclass(unsafe_hash=True, slots=True)
-class GMFTConfig:
-    """Configuration options for GMFT.
+def _pandas_to_polars(pandas_df: Any) -> pl.DataFrame:
+    if pandas_df is None:
+        return pl.DataFrame()
 
-    This class encapsulates the configuration options for GMFT, providing a way to customize its behavior.
-    """
+    try:
+        return pl.from_pandas(pandas_df)
+    except (TypeError, ValueError, AttributeError):
+        if hasattr(pandas_df, "columns") and hasattr(pandas_df.columns, "duplicated"):
+            mask = ~pandas_df.columns.duplicated()
+            pandas_df = pandas_df.loc[:, mask]
+            return pl.from_pandas(pandas_df)
+        return pl.DataFrame()
 
-    verbosity: int = 0
-    """
-    Verbosity level for logging.
 
-    0: errors only
-    1: print warnings
-    2: print warnings and info
-    3: print warnings, info, and debug
-    """
-    formatter_base_threshold: float = 0.3
-    """
-    Base threshold for the confidence demanded of a table feature (row/column).
+def _dataframe_to_markdown(df: Any) -> str:
+    if df is None:
+        return ""
 
-    Note that a low threshold is actually better, because overzealous rows means that generally, numbers are still aligned and there are just many empty rows (having fewer rows than expected merges cells, which is bad).
-    """
-    cell_required_confidence: dict[Literal[0, 1, 2, 3, 4, 5, 6], float] = field(
-        default_factory=lambda: {
-            0: 0.3,
-            1: 0.3,
-            2: 0.3,
-            3: 0.3,
-            4: 0.5,
-            5: 0.5,
-            6: 99,
-        },
-        hash=False,
-    )
-    """
-    Confidences required (>=) for a row/column feature to be considered good. See TATRFormattedTable.id2label
+    if isinstance(df, pl.DataFrame):
+        if df.is_empty():
+            return ""
+        return str(df)
 
-    But low confidences may be better than too high confidence (see formatter_base_threshold)
-    """
-    detector_base_threshold: float = 0.9
-    """Minimum confidence score required for a table"""
-    remove_null_rows: bool = True
-    """
-    Flag to remove rows with no text.
-    """
-    enable_multi_header: bool = False
-    """
-    Enable multi-indices in the dataframe.
+    if hasattr(df, "to_markdown"):
+        return cast("str", df.to_markdown())
 
-    If false, then multiple headers will be merged column-wise.
-    """
-    semantic_spanning_cells: bool = False
-    """
-    [Experimental] Enable semantic spanning cells, which often encode hierarchical multi-level indices.
-    """
-    semantic_hierarchical_left_fill: Literal["algorithm", "deep"] | None = "algorithm"
-    """
-    [Experimental] When semantic spanning cells is enabled, when a left header is detected which might represent a group of rows, that same value is reduplicated for each row.
+    return str(df)
 
-    Possible values: 'algorithm', 'deep', None.
 
-    'algorithm': assumes that the higher-level header is always the first row followed by several empty rows.
-    'deep': merges headers according to the spanning cells detected by the Table Transformer.
-    None: headers are not duplicated.
-    """
-    large_table_if_n_rows_removed: int = 8
-    """
-    If >= n rows are removed due to non-maxima suppression (NMS), then this table is classified as a large table.
-    """
-    large_table_threshold: int = 10
-    """
-    With large tables, table transformer struggles with placing too many overlapping rows. Luckily, with more rows, we have more info on the usual size of text, which we can use to make a guess on the height such that no rows are merged or overlapping.
+def _dataframe_to_csv(df: Any) -> str:
+    if df is None:
+        return ""
 
-    Large table assumption is only applied when (# of rows > large_table_threshold) AND (total overlap > large_table_row_overlap_threshold). Set 9999 to disable; set 0 to force large table assumption to run every time.
-    """
-    large_table_row_overlap_threshold: float = 0.2
-    """
-    With large tables, table transformer struggles with placing too many overlapping rows. Luckily, with more rows, we have more info on the usual size of text, which we can use to make a guess on the height such that no rows are merged or overlapping.
+    if isinstance(df, pl.DataFrame):
+        if df.is_empty():
+            return ""
+        return df.write_csv()
 
-    Large table assumption is only applied when (# of rows > large_table_threshold) AND (total overlap > large_table_row_overlap_threshold).
-    """
-    large_table_maximum_rows: int = 1000
-    """
-    Maximum number of rows allowed for a large table.
-    """
-    force_large_table_assumption: bool | None = None
-    """
-    Force the large table assumption to be applied, regardless of the number of rows and overlap.
-    """
-    total_overlap_reject_threshold: float = 0.9
-    """
-    Reject if total overlap is > 90% of table area.
-    """
-    total_overlap_warn_threshold: float = 0.1
-    """
-    Warn if total overlap is > 10% of table area.
-    """
-    nms_warn_threshold: int = 5
-    """
-    Warn if non maxima suppression removes > 5 rows.
-    """
-    iob_reject_threshold: float = 0.05
-    """
-    Reject if iob between textbox and cell is < 5%.
-    """
-    iob_warn_threshold: float = 0.5
-    """
-    Warn if iob between textbox and cell is < 50%.
-    """
+    if hasattr(df, "to_csv"):
+        return cast("str", df.to_csv(index=False))
+
+    return ""
+
+
+def _is_dataframe_empty(df: Any) -> bool:
+    if df is None:
+        return True
+
+    if isinstance(df, pl.DataFrame):
+        return df.is_empty()
+
+    if hasattr(df, "empty"):
+        return cast("bool", df.empty)
+
+    return True
 
 
 async def extract_tables(
     file_path: str | PathLike[str], config: GMFTConfig | None = None, use_isolated_process: bool | None = None
 ) -> list[TableData]:
-    """Extracts tables from a PDF file.
-
-    This function takes a file path to a PDF file, and an optional configuration object.
-    It returns a list of strings, where each string is a markdown-formatted table.
-
-    Args:
-        file_path: The path to the PDF file.
-        config: An optional configuration object.
-        use_isolated_process: Whether to use an isolated process for extraction.
-            If None, uses environment variable KREUZBERG_GMFT_ISOLATED (default: True).
-
-    Raises:
-        MissingDependencyError: Raised when the required dependencies are not installed.
-
-    Returns:
-        A list of table data dictionaries.
-    """
-    from kreuzberg._utils._cache import get_table_cache  # noqa: PLC0415
-
     # Determine if we should use isolated process  # ~keep
     if use_isolated_process is None:
         use_isolated_process = os.environ.get("KREUZBERG_GMFT_ISOLATED", "true").lower() in ("true", "1", "yes")
@@ -211,15 +138,15 @@ async def extract_tables(
             return result
 
         try:
-            from gmft.auto import (  # type: ignore[attr-defined]  # noqa: PLC0415  # noqa: PLC0415
+            from gmft.auto import (  # type: ignore[attr-defined]  # noqa: PLC0415
                 AutoTableDetector,
                 AutoTableFormatter,
             )
             from gmft.detectors.tatr import TATRDetectorConfig  # type: ignore[attr-defined]  # noqa: PLC0415
-            from gmft.formatters.tatr import TATRFormatConfig  # noqa: PLC0415  # noqa: PLC0415
-            from gmft.pdf_bindings.pdfium import PyPDFium2Document  # noqa: PLC0415  # noqa: PLC0415
+            from gmft.formatters.tatr import TATRFormatConfig  # noqa: PLC0415
+            from gmft.pdf_bindings.pdfium import PyPDFium2Document  # noqa: PLC0415
 
-            formatter: Any = AutoTableFormatter(  # type: ignore[no-untyped-call]  # type: ignore[no-untyped-call]
+            formatter: Any = AutoTableFormatter(  # type: ignore[no-untyped-call]
                 config=TATRFormatConfig(
                     verbosity=config.verbosity,
                     formatter_base_threshold=config.formatter_base_threshold,
@@ -235,12 +162,12 @@ async def extract_tables(
                     force_large_table_assumption=config.force_large_table_assumption,
                 )
             )
-            detector: Any = AutoTableDetector(  # type: ignore[no-untyped-call]  # type: ignore[no-untyped-call]
+            detector: Any = AutoTableDetector(  # type: ignore[no-untyped-call]
                 config=TATRDetectorConfig(detector_base_threshold=config.detector_base_threshold)
             )
             doc = await run_sync(PyPDFium2Document, str(file_path))
             cropped_tables: list[CroppedTable] = []
-            dataframes: list[DataFrame] = []
+            dataframes: list[pl.DataFrame] = []
             try:
                 for page in doc:
                     cropped_tables.extend(await run_sync(detector.extract, page))
@@ -253,8 +180,8 @@ async def extract_tables(
                     TableData(
                         cropped_image=cropped_table.image(),
                         page_number=cropped_table.page.page_number,
-                        text=data_frame.to_markdown(),
-                        df=data_frame,
+                        text=_dataframe_to_markdown(data_frame),
+                        df=_pandas_to_polars(data_frame),
                     )
                     for data_frame, cropped_table in zip(dataframes, cropped_tables, strict=False)
                 ]
@@ -276,19 +203,6 @@ async def extract_tables(
 def extract_tables_sync(
     file_path: str | PathLike[str], config: GMFTConfig | None = None, use_isolated_process: bool | None = None
 ) -> list[TableData]:
-    """Synchronous wrapper for extract_tables.
-
-    Args:
-        file_path: The path to the PDF file.
-        config: An optional configuration object.
-        use_isolated_process: Whether to use an isolated process for extraction.
-            If None, uses environment variable KREUZBERG_GMFT_ISOLATED (default: True).
-
-    Returns:
-        A list of table data dictionaries.
-    """
-    from kreuzberg._utils._cache import get_table_cache  # noqa: PLC0415
-
     # Determine if we should use isolated process  # ~keep
     if use_isolated_process is None:
         use_isolated_process = os.environ.get("KREUZBERG_GMFT_ISOLATED", "true").lower() in ("true", "1", "yes")
@@ -367,7 +281,7 @@ def extract_tables_sync(
                 TableData(
                     cropped_image=cropped_table.image(),
                     page_number=cropped_table.page.page_number,
-                    text=data_frame.to_markdown(),
+                    text=_dataframe_to_markdown(data_frame),
                     df=data_frame,
                 )
                 for data_frame, cropped_table in zip(dataframes, cropped_tables, strict=False)
@@ -390,13 +304,6 @@ def _extract_tables_in_process(
     config_dict: dict[str, Any],
     result_queue: queue.Queue[tuple[bool, Any]],
 ) -> None:
-    """Extract tables in an isolated process to handle potential segfaults.
-
-    Args:
-        file_path: Path to the PDF file
-        config_dict: Serialized GMFTConfig as a dict
-        result_queue: Queue to put results or errors
-    """
     signal.signal(signal.SIGINT, signal.SIG_IGN)
 
     try:
@@ -444,12 +351,14 @@ def _extract_tables_in_process(
                 cropped_image.save(img_bytes, format="PNG")
                 img_bytes.seek(0)
 
+                csv_data = _dataframe_to_csv(data_frame) if not _is_dataframe_empty(data_frame) else ""
                 results.append(
                     {
                         "cropped_image_bytes": img_bytes.getvalue(),
                         "page_number": cropped_table.page.page_number,
-                        "text": data_frame.to_markdown(),
-                        "df_csv": data_frame.to_csv(index=False),
+                        "text": _dataframe_to_markdown(data_frame),
+                        "df_columns": data_frame.columns,
+                        "df_csv": csv_data if csv_data else None,
                     }
                 )
 
@@ -468,19 +377,6 @@ def _extract_tables_isolated(
     config: GMFTConfig | None = None,
     timeout: float = 300.0,
 ) -> list[TableData]:
-    """Extract tables using an isolated process to handle segfaults.
-
-    Args:
-        file_path: Path to the PDF file
-        config: GMFT configuration
-        timeout: Maximum time to wait for extraction
-
-    Returns:
-        List of extracted tables
-
-    Raises:
-        RuntimeError: If extraction fails or times out
-    """
     config = config or GMFTConfig()
     config_dict = msgspec.to_builtins(config)
 
@@ -530,9 +426,11 @@ def _extract_tables_isolated(
             tables = []
             for table_dict in result:
                 img = Image.open(io.BytesIO(table_dict["cropped_image_bytes"]))
-                import pandas as pd  # noqa: PLC0415
 
-                df = pd.read_csv(StringIO(table_dict["df_csv"]))
+                if table_dict["df_csv"] is None or table_dict["df_csv"] == "":
+                    df = pl.DataFrame()
+                else:
+                    df = pl.read_csv(StringIO(table_dict["df_csv"]), truncate_ragged_lines=True)
 
                 tables.append(
                     TableData(
@@ -577,19 +475,6 @@ async def _extract_tables_isolated_async(
     config: GMFTConfig | None = None,
     timeout: float = 300.0,  # noqa: ASYNC109
 ) -> list[TableData]:
-    """Async version of extract_tables_isolated using asyncio.
-
-    Args:
-        file_path: Path to the PDF file
-        config: GMFT configuration
-        timeout: Maximum time to wait for extraction
-
-    Returns:
-        List of extracted tables
-
-    Raises:
-        RuntimeError: If extraction fails or times out
-    """
     config = config or GMFTConfig()
     config_dict = msgspec.to_builtins(config)
 
@@ -605,40 +490,34 @@ async def _extract_tables_isolated_async(
 
     try:
 
-        async def wait_for_result() -> tuple[bool, Any]:
+        def get_result_sync() -> tuple[bool, Any]:
             while True:
                 try:
-                    return result_queue.get_nowait()  # type: ignore[no-any-return]
+                    return result_queue.get(timeout=0.1)  # type: ignore[no-any-return]
                 except queue.Empty:  # noqa: PERF203
-                    await anyio.sleep(0.1)
                     if not process.is_alive():
-                        # Process died without putting result  # ~keep
                         if process.exitcode == -signal.SIGSEGV:
                             raise ParsingError(
                                 "GMFT process crashed with segmentation fault",
-                                context={
-                                    "file_path": str(file_path),
-                                    "exit_code": process.exitcode,
-                                },
+                                context={"file_path": str(file_path), "exit_code": process.exitcode},
                             ) from None
                         raise ParsingError(
                             f"GMFT process died unexpectedly with exit code {process.exitcode}",
-                            context={
-                                "file_path": str(file_path),
-                                "exit_code": process.exitcode,
-                            },
+                            context={"file_path": str(file_path), "exit_code": process.exitcode},
                         ) from None
 
         with anyio.fail_after(timeout):
-            success, result = await wait_for_result()
+            success, result = await anyio.to_thread.run_sync(get_result_sync)
 
         if success:
             tables = []
             for table_dict in result:
                 img = Image.open(io.BytesIO(table_dict["cropped_image_bytes"]))
-                import pandas as pd  # noqa: PLC0415
 
-                df = pd.read_csv(StringIO(table_dict["df_csv"]))
+                if table_dict["df_csv"] is None or table_dict["df_csv"] == "":
+                    df = pl.DataFrame()
+                else:
+                    df = pl.read_csv(StringIO(table_dict["df_csv"]), truncate_ragged_lines=True)
 
                 tables.append(
                     TableData(
