@@ -4,18 +4,14 @@ from typing import TYPE_CHECKING, Any
 from unittest.mock import AsyncMock, Mock, patch
 
 import pytest
-from litestar.testing import AsyncTestClient
 
-from kreuzberg._api.main import app, exception_handler
+from kreuzberg._api.main import exception_handler
 from kreuzberg.exceptions import OCRError, ParsingError, ValidationError
 
 if TYPE_CHECKING:
     from pathlib import Path
 
-
-@pytest.fixture
-def test_client() -> AsyncTestClient[Any]:
-    return AsyncTestClient(app=app)
+    from litestar.testing import AsyncTestClient
 
 
 @pytest.mark.anyio
@@ -71,13 +67,14 @@ async def test_extract_from_file_extraction_error(test_client: AsyncTestClient[A
     assert response.status_code == 500
     error_response = response.json()
 
-    assert "detail" in error_response
-    assert error_response["status_code"] == 500
+    assert "error_type" in error_response
+    assert "message" in error_response
+    assert error_response["error_type"] == "Exception"
+    assert error_response["message"] == "Test error"
 
 
 @pytest.mark.anyio
 async def test_extract_validation_error_response(test_client: AsyncTestClient[Any], tmp_path: Path) -> None:
-    """Test that ValidationError is properly handled by the API."""
     test_file = tmp_path / "test.txt"
     test_file.write_text("hello world")
 
@@ -94,7 +91,6 @@ async def test_extract_validation_error_response(test_client: AsyncTestClient[An
 
 @pytest.mark.anyio
 async def test_extract_parsing_error_response(test_client: AsyncTestClient[Any], tmp_path: Path) -> None:
-    """Test that ParsingError is properly handled by the API."""
     test_file = tmp_path / "test.txt"
     test_file.write_text("hello world")
 
@@ -111,7 +107,6 @@ async def test_extract_parsing_error_response(test_client: AsyncTestClient[Any],
 
 @pytest.mark.anyio
 async def test_extract_ocr_error_response(test_client: AsyncTestClient[Any], tmp_path: Path) -> None:
-    """Test that OCRError is properly handled by the API."""
     test_file = tmp_path / "test.txt"
     test_file.write_text("hello world")
 
@@ -301,10 +296,7 @@ async def test_extract_non_ascii_pdf(test_client: AsyncTestClient[Any], non_asci
     assert data[0]["mime_type"] in ["text/plain", "text/markdown"]
 
 
-# Test exception handler directly
 def test_exception_handler_validation_error() -> None:
-    """Test exception handler with ValidationError."""
-    # Create mock request
     mock_request = Mock()
     mock_request.method = "POST"
     mock_request.url = "http://test.com/extract"
@@ -312,7 +304,6 @@ def test_exception_handler_validation_error() -> None:
     mock_app.logger = Mock()
     mock_request.app = mock_app
 
-    # Create ValidationError
     error = ValidationError("Invalid input", context={"field": "test"})
 
     response = exception_handler(mock_request, error)
@@ -321,7 +312,6 @@ def test_exception_handler_validation_error() -> None:
     assert "Invalid input" in response.content["message"]
     assert '"field": "test"' in response.content["details"]
 
-    # Verify logging was called
     mock_app.logger.error.assert_called_once()
     call_args = mock_app.logger.error.call_args
     assert call_args[0][0] == "API error"
@@ -330,8 +320,6 @@ def test_exception_handler_validation_error() -> None:
 
 
 def test_exception_handler_parsing_error() -> None:
-    """Test exception handler with ParsingError."""
-    # Create mock request
     mock_request = Mock()
     mock_request.method = "GET"
     mock_request.url = "http://test.com/health"
@@ -339,7 +327,6 @@ def test_exception_handler_parsing_error() -> None:
     mock_app.logger = Mock()
     mock_request.app = mock_app
 
-    # Create ParsingError
     error = ParsingError("Failed to parse document", context={"file": "test.pdf"})
 
     response = exception_handler(mock_request, error)
@@ -350,8 +337,6 @@ def test_exception_handler_parsing_error() -> None:
 
 
 def test_exception_handler_other_error() -> None:
-    """Test exception handler with other KreuzbergError (OCRError)."""
-    # Create mock request
     mock_request = Mock()
     mock_request.method = "POST"
     mock_request.url = "http://test.com/extract"
@@ -359,7 +344,6 @@ def test_exception_handler_other_error() -> None:
     mock_app.logger = Mock()
     mock_request.app = mock_app
 
-    # Create OCRError (other KreuzbergError)
     error = OCRError("OCR processing failed", context={"engine": "tesseract"})
 
     response = exception_handler(mock_request, error)
@@ -370,19 +354,15 @@ def test_exception_handler_other_error() -> None:
 
 
 def test_exception_handler_no_logger() -> None:
-    """Test exception handler when request.app.logger is None."""
-    # Create mock request without logger
     mock_request = Mock()
     mock_request.method = "POST"
     mock_request.url = "http://test.com/extract"
     mock_app = Mock()
-    mock_app.logger = None  # No logger
+    mock_app.logger = None
     mock_request.app = mock_app
 
-    # Create ValidationError
     error = ValidationError("Invalid input", context={"field": "test"})
 
-    # Should not raise exception even without logger
     response = exception_handler(mock_request, error)
 
     assert response.status_code == 400
@@ -390,13 +370,8 @@ def test_exception_handler_no_logger() -> None:
 
 
 def test_import_error_handling() -> None:
-    """Test that ImportError handling works correctly."""
-    # Test the import error structure by examining the code directly
-    # We can't easily test the actual import failure due to caching,
-    # but we can test that MissingDependencyError.create_for_package works
     from kreuzberg.exceptions import MissingDependencyError
 
-    # Test that the exception creation works as expected
     import_error = ImportError("No module named 'litestar'")
     try:
         raise MissingDependencyError.create_for_package(
@@ -409,18 +384,11 @@ def test_import_error_handling() -> None:
         assert e.__cause__ is import_error
 
 
-# =============================================================================
-# COMPREHENSIVE TESTS FOR API MODULE
-# =============================================================================
-
-
 @pytest.mark.anyio
 async def test_get_configuration_no_config(
     test_client: AsyncTestClient[Any], tmp_path: Path, monkeypatch: pytest.MonkeyPatch
 ) -> None:
-    """Test GET /config when no configuration file exists."""
-    # Mock try_discover_config to return None
-    with patch("kreuzberg._api.main.try_discover_config", return_value=None):
+    with patch("kreuzberg._api.main.discover_config", return_value=None):
         response = await test_client.get("/config")
 
     assert response.status_code == 200
@@ -431,11 +399,8 @@ async def test_get_configuration_no_config(
 
 @pytest.mark.anyio
 async def test_get_configuration_with_config(test_client: AsyncTestClient[Any]) -> None:
-    """Test GET /config when configuration file exists."""
-    from kreuzberg import ExtractionConfig
-    from kreuzberg._ocr._tesseract import PSMMode, TesseractConfig
+    from kreuzberg import ExtractionConfig, PSMMode, TesseractConfig
 
-    # Create a test config
     test_config = ExtractionConfig(
         ocr_backend="tesseract",
         ocr_config=TesseractConfig(language="fra", psm=PSMMode.SINGLE_BLOCK),
@@ -445,8 +410,7 @@ async def test_get_configuration_with_config(test_client: AsyncTestClient[Any])
         max_chars=5000,
     )
 
-    # Mock try_discover_config to return our test config
-    with patch("kreuzberg._api.main.try_discover_config", return_value=test_config):
+    with patch("kreuzberg._api.main.discover_config", return_value=test_config):
         response = await test_client.get("/config")
 
     assert response.status_code == 200
@@ -462,15 +426,11 @@ async def test_get_configuration_with_config(test_client: AsyncTestClient[Any])
 
 @pytest.mark.anyio
 async def test_extract_with_discovered_config(test_client: AsyncTestClient[Any], searchable_pdf: Path) -> None:
-    """Test that extraction uses discovered config."""
     from kreuzberg import ExtractionConfig
 
-    # Create a test config with specific settings
     test_config = ExtractionConfig(chunk_content=True, max_chars=1000, max_overlap=200)
 
-    # Mock try_discover_config to return our test config
-    with patch("kreuzberg._api.main.try_discover_config", return_value=test_config):
-        # Mock batch_extract_bytes to verify config is passed
+    with patch("kreuzberg._api.main.discover_config", return_value=test_config):
         with patch("kreuzberg._api.main.batch_extract_bytes", new_callable=AsyncMock) as mock_extract:
             mock_extract.return_value = [
                 {"content": "Test content", "mime_type": "text/plain", "metadata": {}, "chunks": ["chunk1", "chunk2"]}
@@ -481,7 +441,6 @@ async def test_extract_with_discovered_config(test_client: AsyncTestClient[Any],
                     "/extract", files=[("data", (searchable_pdf.name, f.read(), "application/pdf"))]
                 )
 
-            # Verify batch_extract_bytes was called with the discovered config
             assert mock_extract.called
             call_args = mock_extract.call_args
             used_config = call_args[1]["config"]
@@ -494,10 +453,7 @@ async def test_extract_with_discovered_config(test_client: AsyncTestClient[Any],
 
 @pytest.mark.anyio
 async def test_extract_without_discovered_config(test_client: AsyncTestClient[Any], searchable_pdf: Path) -> None:
-    """Test that extraction uses default config when none discovered."""
-    # Mock try_discover_config to return None
-    with patch("kreuzberg._api.main.try_discover_config", return_value=None):
-        # Mock batch_extract_bytes to verify default config is used
+    with patch("kreuzberg._api.main.discover_config", return_value=None):
         with patch("kreuzberg._api.main.batch_extract_bytes", new_callable=AsyncMock) as mock_extract:
             mock_extract.return_value = [
                 {"content": "Test content", "mime_type": "text/plain", "metadata": {}, "chunks": []}
@@ -508,21 +464,17 @@ async def test_extract_without_discovered_config(test_client: AsyncTestClient[An
                     "/extract", files=[("data", (searchable_pdf.name, f.read(), "application/pdf"))]
                 )
 
-            # Verify batch_extract_bytes was called with default config
             assert mock_extract.called
             call_args = mock_extract.call_args
             used_config = call_args[1]["config"]
-            # Default config should have default values
             assert used_config.chunk_content is False
-            assert used_config.max_chars == 2000  # Default value
+            assert used_config.max_chars == 2000
 
     assert response.status_code == 201
 
 
 @pytest.mark.anyio
 async def test_extract_large_file_list(test_client: AsyncTestClient[Any], tmp_path: Path) -> None:
-    """Test extraction with many files."""
-    # Create 20 test files
     files = []
     for i in range(20):
         test_file = tmp_path / f"test_{i}.txt"
@@ -541,25 +493,20 @@ async def test_extract_large_file_list(test_client: AsyncTestClient[Any], tmp_pa
 
 @pytest.mark.anyio
 async def test_extract_with_custom_mime_types(test_client: AsyncTestClient[Any], tmp_path: Path) -> None:
-    """Test extraction with various MIME type scenarios."""
     test_file = tmp_path / "test.bin"
     test_file.write_bytes(b"binary content")
 
-    # Test with no MIME type (should infer)
     with test_file.open("rb") as f:
         response = await test_client.post("/extract", files=[("data", (test_file.name, f.read()))])
 
-    # Even unknown files might be processed (e.g., as text)
     assert response.status_code in [201, 400, 422]
 
 
 @pytest.mark.anyio
 async def test_extract_file_with_none_content_type(test_client: AsyncTestClient[Any], tmp_path: Path) -> None:
-    """Test extraction when content_type is None."""
     test_file = tmp_path / "test.txt"
     test_file.write_text("Hello world")
 
-    # Mock UploadFile with None content_type
     with patch("kreuzberg._api.main.batch_extract_bytes", new_callable=AsyncMock) as mock_extract:
         mock_extract.return_value = [
             {"content": "Hello world", "mime_type": "text/plain", "metadata": {}, "chunks": []}
@@ -568,29 +515,23 @@ async def test_extract_file_with_none_content_type(test_client: AsyncTestClient[
         with test_file.open("rb") as f:
             response = await test_client.post(
                 "/extract",
-                files=[("data", (test_file.name, f.read(), None))],  # None content_type
+                files=[("data", (test_file.name, f.read(), None))],
             )
 
-        # Verify the None was passed through
         assert mock_extract.called
         call_args = mock_extract.call_args[0][0]
         assert len(call_args) == 1
-        # The second element of the tuple should be None
-        # (since we mocked it, we can't easily verify this part)
 
     assert response.status_code == 201
 
 
 @pytest.mark.anyio
 async def test_health_check_idempotent(test_client: AsyncTestClient[Any]) -> None:
-    """Test that health check is idempotent."""
-    # Call health check multiple times
     responses = []
     for _ in range(5):
         response = await test_client.get("/health")
         responses.append(response)
 
-    # All should be successful and identical
     for response in responses:
         assert response.status_code == 200
         assert response.json() == {"status": "ok"}
@@ -598,7 +539,6 @@ async def test_health_check_idempotent(test_client: AsyncTestClient[Any]) -> Non
 
 @pytest.mark.anyio
 async def test_extract_memory_error_handling(test_client: AsyncTestClient[Any], tmp_path: Path) -> None:
-    """Test handling of MemoryError during extraction."""
     test_file = tmp_path / "test.txt"
     test_file.write_text("test content")
 
@@ -608,12 +548,10 @@ async def test_extract_memory_error_handling(test_client: AsyncTestClient[Any],
         with test_file.open("rb") as f:
             response = await test_client.post("/extract", files=[("data", (test_file.name, f.read(), "text/plain"))])
 
-    # MemoryError is not a KreuzbergError, so it should be 500
     assert response.status_code == 500
 
 
 def test_exception_handler_with_empty_context() -> None:
-    """Test exception handler with empty context."""
     mock_request = Mock()
     mock_request.method = "POST"
     mock_request.url = "http://test.com/extract"
@@ -621,7 +559,6 @@ def test_exception_handler_with_empty_context() -> None:
     mock_app.logger = Mock()
     mock_request.app = mock_app
 
-    # Create error with empty context
     error = ValidationError("Test error", context={})
 
     response = exception_handler(mock_request, error)
@@ -632,7 +569,6 @@ def test_exception_handler_with_empty_context() -> None:
 
 
 def test_exception_handler_context_serialization() -> None:
-    """Test exception handler with complex context that needs JSON serialization."""
     mock_request = Mock()
     mock_request.method = "POST"
     mock_request.url = "http://test.com/extract"
@@ -640,7 +576,6 @@ def test_exception_handler_context_serialization() -> None:
     mock_app.logger = Mock()
     mock_request.app = mock_app
 
-    # Create error with complex context
     error = ParsingError(
         "Complex error",
         context={"numbers": [1, 2, 3], "nested": {"key": "value"}, "boolean": True, "none": None, "float": 3.14},
@@ -649,7 +584,6 @@ def test_exception_handler_context_serialization() -> None:
     response = exception_handler(mock_request, error)
 
     assert response.status_code == 422
-    # Verify JSON serialization worked
     assert '"numbers": [1, 2, 3]' in response.content["details"]
     assert '"nested": {"key": "value"}' in response.content["details"]
     assert '"boolean": true' in response.content["details"]
@@ -659,14 +593,10 @@ def test_exception_handler_context_serialization() -> None:
 
 @pytest.mark.anyio
 async def test_api_routes_registration(test_client: AsyncTestClient[Any]) -> None:
-    """Test that all expected routes are registered."""
-    # Get the app's route handler map
     from kreuzberg._api.main import app
 
-    # Check that all expected routes exist
     routes = [(route.path, route.methods) for route in app.routes if hasattr(route, "path")]
 
-    # Verify expected routes
     expected_routes = [("/extract", ["POST"]), ("/health", ["GET"]), ("/config", ["GET"])]
 
     for path, methods in expected_routes:
@@ -682,51 +612,206 @@ async def test_api_routes_registration(test_client: AsyncTestClient[Any]) -> Non
 
 @pytest.mark.anyio
 async def test_opentelemetry_plugin_loaded() -> None:
-    """Test that OpenTelemetry plugin is loaded."""
     from kreuzberg._api.main import app
 
-    # Check that OpenTelemetryPlugin is in the app's plugins
     plugin_types = [type(plugin).__name__ for plugin in app.plugins]
     assert "OpenTelemetryPlugin" in plugin_types
 
 
 @pytest.mark.anyio
 async def test_structured_logging_configured() -> None:
-    """Test that structured logging is configured."""
     from kreuzberg._api.main import app
 
-    # Check that StructLoggingConfig is used
     assert app.logging_config is not None
     assert type(app.logging_config).__name__ == "StructLoggingConfig"
 
 
 @pytest.mark.anyio
 async def test_exception_handlers_registered() -> None:
-    """Test that exception handlers are properly registered."""
     from kreuzberg._api.main import app
     from kreuzberg.exceptions import KreuzbergError
 
-    # Check that KreuzbergError handler is registered
     assert KreuzbergError in app.exception_handlers
 
 
 @pytest.mark.anyio
 async def test_msgspec_serialization_deterministic(test_client: AsyncTestClient[Any]) -> None:
-    """Test that msgspec serialization is deterministic."""
     import msgspec
 
     from kreuzberg import ExtractionConfig
 
-    # Create a config with nested structures
     config = ExtractionConfig(
         ocr_backend="tesseract", extract_tables=True, chunk_content=True, max_chars=5000, max_overlap=1000
     )
 
-    # Serialize multiple times
     serialized_results = []
     for _ in range(5):
         serialized = msgspec.to_builtins(config, order="deterministic")
         serialized_results.append(str(serialized))
 
-    # All serializations should be identical
     assert all(s == serialized_results[0] for s in serialized_results)
+
+
+@pytest.mark.anyio
+async def test_extract_with_invalid_config_file(test_client: AsyncTestClient[Any], tmp_path: Path) -> None:
+    from kreuzberg.exceptions import ValidationError
+
+    with patch("kreuzberg._api.main.discover_config") as mock_discover:
+        mock_discover.side_effect = ValidationError(
+            "Invalid TOML in configuration file: Expected '=' after key",
+            context={"file": "/path/to/kreuzberg.toml", "error": "TOML parse error"},
+        )
+
+        test_file = tmp_path / "test.txt"
+        test_file.write_text("test content")
+
+        with test_file.open("rb") as f:
+            response = await test_client.post("/extract", files=[("data", (test_file.name, f.read(), "text/plain"))])
+
+    assert response.status_code == 400
+    error_response = response.json()
+    assert "Invalid TOML in configuration file" in error_response["message"]
+    assert "TOML parse error" in error_response["details"]
+    assert "/path/to/kreuzberg.toml" in error_response["details"]
+
+
+@pytest.mark.anyio
+async def test_get_config_with_invalid_config_file(test_client: AsyncTestClient[Any]) -> None:
+    from kreuzberg.exceptions import ValidationError
+
+    with patch("kreuzberg._api.main.discover_config") as mock_discover:
+        mock_discover.side_effect = ValidationError(
+            "Invalid OCR backend: unknown. Must be one of: easyocr, paddleocr, tesseract or 'none'",
+            context={"provided": "unknown", "valid": ["easyocr", "paddleocr", "tesseract"]},
+        )
+
+        response = await test_client.get("/config")
+
+    assert response.status_code == 400
+    error_response = response.json()
+    assert "Invalid OCR backend: unknown" in error_response["message"]
+    assert '"provided": "unknown"' in error_response["details"]
+    assert "easyocr" in error_response["details"]
+
+
+@pytest.mark.anyio
+async def test_extract_with_invalid_ocr_config(test_client: AsyncTestClient[Any], tmp_path: Path) -> None:
+    from kreuzberg.exceptions import ValidationError
+
+    with patch("kreuzberg._api.main.discover_config") as mock_discover:
+        mock_discover.side_effect = ValidationError(
+            "Invalid configuration for OCR backend 'tesseract': Invalid PSM mode value: 99",
+            context={"psm_value": 99, "error": "99 is not a valid PSMMode"},
+        )
+
+        test_file = tmp_path / "test.txt"
+        test_file.write_text("test content")
+
+        with test_file.open("rb") as f:
+            response = await test_client.post("/extract", files=[("data", (test_file.name, f.read(), "text/plain"))])
+
+    assert response.status_code == 400
+    error_response = response.json()
+    assert "Invalid PSM mode value: 99" in error_response["message"]
+    assert '"psm_value": 99' in error_response["details"]
+
+
+@pytest.mark.anyio
+async def test_extract_with_invalid_gmft_config(test_client: AsyncTestClient[Any], tmp_path: Path) -> None:
+    from kreuzberg.exceptions import ValidationError
+
+    with patch("kreuzberg._api.main.discover_config") as mock_discover:
+        mock_discover.side_effect = ValidationError(
+            "Invalid GMFT configuration: Invalid parameter 'invalid_param'",
+            context={"gmft_config": {"invalid_param": "value"}, "error": "Unknown parameter"},
+        )
+
+        test_file = tmp_path / "test.pdf"
+        test_file.write_bytes(b"%PDF-1.4")
+
+        with test_file.open("rb") as f:
+            response = await test_client.post(
+                "/extract", files=[("data", (test_file.name, f.read(), "application/pdf"))]
+            )
+
+    assert response.status_code == 400
+    error_response = response.json()
+    assert "Invalid GMFT configuration" in error_response["message"]
+    assert "invalid_param" in error_response["details"]
+
+
+@pytest.mark.anyio
+async def test_extract_with_unreadable_config_file(test_client: AsyncTestClient[Any], tmp_path: Path) -> None:
+    from kreuzberg.exceptions import ValidationError
+
+    with patch("kreuzberg._api.main.discover_config") as mock_discover:
+        mock_discover.side_effect = ValidationError(
+            "Failed to read pyproject.toml: Permission denied",
+            context={"file": "/path/to/pyproject.toml", "error": "Permission denied"},
+        )
+
+        test_file = tmp_path / "test.txt"
+        test_file.write_text("test content")
+
+        with test_file.open("rb") as f:
+            response = await test_client.post("/extract", files=[("data", (test_file.name, f.read(), "text/plain"))])
+
+    assert response.status_code == 400
+    error_response = response.json()
+    assert "Failed to read pyproject.toml" in error_response["message"]
+    assert "Permission denied" in error_response["details"]
+    assert "/path/to/pyproject.toml" in error_response["details"]
+
+
+@pytest.mark.anyio
+async def test_extract_with_invalid_extraction_config(test_client: AsyncTestClient[Any], tmp_path: Path) -> None:
+    from kreuzberg.exceptions import ValidationError
+
+    with patch("kreuzberg._api.main.discover_config") as mock_discover:
+        mock_discover.side_effect = ValidationError(
+            "Invalid extraction configuration: max_chars must be positive",
+            context={"config": {"max_chars": -100}, "error": "Negative max_chars"},
+        )
+
+        test_file = tmp_path / "test.txt"
+        test_file.write_text("test content")
+
+        with test_file.open("rb") as f:
+            response = await test_client.post("/extract", files=[("data", (test_file.name, f.read(), "text/plain"))])
+
+    assert response.status_code == 400
+    error_response = response.json()
+    assert "Invalid extraction configuration" in error_response["message"]
+    assert "max_chars must be positive" in error_response["message"]
+    assert '"max_chars": -100' in error_response["details"]
+
+
+@pytest.mark.anyio
+async def test_extract_pdf_without_tables_with_table_extraction_enabled(
+    test_client: AsyncTestClient[Any], searchable_pdf: Path
+) -> None:
+    from kreuzberg import ExtractionConfig, GMFTConfig
+
+    test_config = ExtractionConfig(
+        extract_tables=True,
+        gmft_config=GMFTConfig(
+            detector_base_threshold=0.9,
+            remove_null_rows=True,
+        ),
+    )
+
+    with patch("kreuzberg._api.main.discover_config", return_value=test_config):
+        with searchable_pdf.open("rb") as f:
+            response = await test_client.post(
+                "/extract", files=[("data", (searchable_pdf.name, f.read(), "application/pdf"))]
+            )
+
+    assert response.status_code == 201
+    data = response.json()
+    assert len(data) == 1
+    assert "content" in data[0]
+
+    assert "Sample PDF" in data[0]["content"]
+
+    if "tables" in data[0]:
+        assert isinstance(data[0]["tables"], list)
