@@ -1,5 +1,3 @@
-"""Tests for OCR base classes."""
-
 from __future__ import annotations
 
 from typing import TYPE_CHECKING
@@ -16,27 +14,20 @@ if TYPE_CHECKING:
 
 
 class TestOCRBackend(OCRBackend[dict[str, object]]):
-    """Test implementation of OCRBackend."""
-
     async def process_image(self, image: Image.Image, **kwargs: dict[str, object]) -> ExtractionResult:
-        """Test implementation of process_image."""
         return ExtractionResult(content="Test OCR result", mime_type="text/plain", metadata={}, chunks=[])
 
     async def process_file(self, path: Path, **kwargs: dict[str, object]) -> ExtractionResult:
-        """Test implementation of process_file."""
         return ExtractionResult(content="Test file OCR result", mime_type="text/plain", metadata={}, chunks=[])
 
     def process_image_sync(self, image: Image.Image, **kwargs: dict[str, object]) -> ExtractionResult:
-        """Test implementation of process_image_sync."""
         return ExtractionResult(content="Test OCR result", mime_type="text/plain", metadata={}, chunks=[])
 
     def process_file_sync(self, path: Path, **kwargs: dict[str, object]) -> ExtractionResult:
-        """Test implementation of process_file_sync."""
         return ExtractionResult(content="Test file OCR result", mime_type="text/plain", metadata={}, chunks=[])
 
 
 def test_ocr_backend_hash() -> None:
-    """Test OCR backend hash method."""
     backend1 = TestOCRBackend()
     backend2 = TestOCRBackend()
 
@@ -45,8 +36,6 @@ def test_ocr_backend_hash() -> None:
 
 
 def test_ocr_backend_different_types_different_hash() -> None:
-    """Test that different OCR backend types have different hashes."""
-
     class AnotherTestBackend(OCRBackend[dict[str, object]]):
         async def process_image(self, image: Image.Image, **kwargs: dict[str, object]) -> ExtractionResult:
             return ExtractionResult(content="", mime_type="text/plain", metadata={}, chunks=[])
@@ -68,7 +57,6 @@ def test_ocr_backend_different_types_different_hash() -> None:
 
 @pytest.mark.anyio
 async def test_ocr_backend_process_image() -> None:
-    """Test OCR backend process_image method."""
     backend = TestOCRBackend()
     image = Mock(spec=Image.Image)
 
@@ -81,7 +69,6 @@ async def test_ocr_backend_process_image() -> None:
 
 @pytest.mark.anyio
 async def test_ocr_backend_process_file(tmp_path: Path) -> None:
-    """Test OCR backend process_file method."""
     backend = TestOCRBackend()
     test_file = tmp_path / "test.txt"
     test_file.write_text("Test content")
