@@ -1,5 +1,3 @@
-"""Tests for the cache utility module."""
-
 from __future__ import annotations
 
 import os
@@ -14,6 +12,10 @@ import pytest
 from kreuzberg._types import ExtractionResult
 from kreuzberg._utils._cache import (
     KreuzbergCache,
+    _document_cache_ref,
+    _mime_cache_ref,
+    _ocr_cache_ref,
+    _table_cache_ref,
     clear_all_caches,
     get_document_cache,
     get_mime_cache,
@@ -27,21 +29,18 @@ if TYPE_CHECKING:
 
 @pytest.fixture
 def temp_cache_dir() -> Generator[Path, None, None]:
-    """Create a temporary cache directory."""
     with tempfile.TemporaryDirectory() as temp_dir:
         yield Path(temp_dir)
 
 
 @pytest.fixture
 def cache(temp_cache_dir: Path) -> KreuzbergCache[ExtractionResult]:
-    """Create a test cache instance."""
     return KreuzbergCache[ExtractionResult](
         cache_type="test", cache_dir=temp_cache_dir, max_cache_size_mb=10.0, max_age_days=1
     )
 
 
 def test_cache_init_default_dir() -> None:
-    """Test cache initialization with default directory."""
     cache = KreuzbergCache[str](cache_type="test")
 
     expected_dir = Path.cwd() / ".kreuzberg" / "test"
@@ -52,7 +51,6 @@ def test_cache_init_default_dir() -> None:
 
 
 def test_cache_init_custom_dir(temp_cache_dir: Path) -> None:
-    """Test cache initialization with custom directory."""
     cache = KreuzbergCache[str](cache_type="custom", cache_dir=temp_cache_dir, max_cache_size_mb=100.0, max_age_days=7)
 
     assert cache.cache_dir == temp_cache_dir
@@ -62,7 +60,6 @@ def test_cache_init_custom_dir(temp_cache_dir: Path) -> None:
 
 
 def test_get_cache_key(cache: KreuzbergCache[ExtractionResult]) -> None:
-    """Test cache key generation."""
     key1 = cache._get_cache_key(file_path="/test/file.pdf", config="default")
     key2 = cache._get_cache_key(config="default", file_path="/test/file.pdf")
     key3 = cache._get_cache_key(file_path="/test/other.pdf", config="default")
@@ -78,7 +75,6 @@ def test_get_cache_key(cache: KreuzbergCache[ExtractionResult]) -> None:
 
 
 def test_get_cache_path(cache: KreuzbergCache[ExtractionResult]) -> None:
-    """Test cache path generation."""
     cache_key = "test1234567890ab"
     cache_path = cache._get_cache_path(cache_key)
 
@@ -87,13 +83,11 @@ def test_get_cache_path(cache: KreuzbergCache[ExtractionResult]) -> None:
 
 
 def test_is_cache_valid_nonexistent(cache: KreuzbergCache[ExtractionResult]) -> None:
-    """Test cache validity check for non-existent file."""
     cache_path = cache.cache_dir / "nonexistent.msgpack"
     assert not cache._is_cache_valid(cache_path)
 
 
 def test_is_cache_valid_fresh_file(cache: KreuzbergCache[ExtractionResult]) -> None:
-    """Test cache validity check for fresh file."""
     cache_path = cache.cache_dir / "fresh.msgpack"
     cache_path.write_text("test content")
 
@@ -101,7 +95,6 @@ def test_is_cache_valid_fresh_file(cache: KreuzbergCache[ExtractionResult]) -> N
 
 
 def test_is_cache_valid_old_file(cache: KreuzbergCache[ExtractionResult]) -> None:
-    """Test cache validity check for old file."""
     cache_path = cache.cache_dir / "old.msgpack"
     cache_path.write_text("test content")
 
@@ -112,7 +105,6 @@ def test_is_cache_valid_old_file(cache: KreuzbergCache[ExtractionResult]) -> Non
 
 
 def test_is_cache_valid_os_error(cache: KreuzbergCache[ExtractionResult]) -> None:
-    """Test cache validity check with OS error."""
     cache_path = cache.cache_dir / "error.msgpack"
 
     with patch("pathlib.Path.stat", side_effect=OSError("Permission denied")):
@@ -120,7 +112,6 @@ def test_is_cache_valid_os_error(cache: KreuzbergCache[ExtractionResult]) -> Non
 
 
 def test_serialize_result(cache: KreuzbergCache[ExtractionResult]) -> None:
-    """Test result serialization."""
     result = ExtractionResult(content="Test content", mime_type="text/plain", metadata={}, chunks=[], tables=[])
 
     serialized = cache._serialize_result(result)
@@ -132,7 +123,6 @@ def test_serialize_result(cache: KreuzbergCache[ExtractionResult]) -> None:
 
 
 def test_deserialize_result_extraction_result(cache: KreuzbergCache[ExtractionResult]) -> None:
-    """Test ExtractionResult deserialization."""
     result_data = {
         "content": "Test content",
         "mime_type": "text/plain",
@@ -152,7 +142,6 @@ def test_deserialize_result_extraction_result(cache: KreuzbergCache[ExtractionRe
 
 
 def test_deserialize_result_regular_object(cache: KreuzbergCache[str]) -> None:
-    """Test regular object deserialization."""
     cached_data = {"type": "str", "data": "test string", "cached_at": time.time()}
 
     deserialized = cache._deserialize_result(cached_data)
@@ -160,8 +149,6 @@ def test_deserialize_result_regular_object(cache: KreuzbergCache[str]) -> None:
 
 
 def test_get_hit(cache: KreuzbergCache[str]) -> None:
-    """Test synchronous cache hit."""
-
     cache.set("test_value", key1="value1", key2="value2")
 
     result = cache.get(key1="value1", key2="value2")
@@ -169,13 +156,11 @@ def test_get_hit(cache: KreuzbergCache[str]) -> None:
 
 
 def test_get_miss(cache: KreuzbergCache[str]) -> None:
-    """Test synchronous cache miss."""
     result = cache.get(key1="nonexistent")
     assert result is None
 
 
 def test_set(cache: KreuzbergCache[str]) -> None:
-    """Test synchronous cache set."""
     cache.set("test_value", key1="value1", key2="value2")
 
     cache_key = cache._get_cache_key(key1="value1", key2="value2")
@@ -188,8 +173,6 @@ def test_set(cache: KreuzbergCache[str]) -> None:
 
 @pytest.mark.anyio
 async def test_aget_hit(cache: KreuzbergCache[str]) -> None:
-    """Test asynchronous cache hit."""
-
     await cache.aset("test_value", key1="value1", key2="value2")
 
     result = await cache.aget(key1="value1", key2="value2")
@@ -198,14 +181,12 @@ async def test_aget_hit(cache: KreuzbergCache[str]) -> None:
 
 @pytest.mark.anyio
 async def test_aget_miss(cache: KreuzbergCache[str]) -> None:
-    """Test asynchronous cache miss."""
     result = await cache.aget(key1="nonexistent")
     assert result is None
 
 
 @pytest.mark.anyio
 async def test_aset(cache: KreuzbergCache[str]) -> None:
-    """Test asynchronous cache set."""
     await cache.aset("test_value", key1="value1", key2="value2")
 
     cache_key = cache._get_cache_key(key1="value1", key2="value2")
@@ -217,8 +198,6 @@ async def test_aset(cache: KreuzbergCache[str]) -> None:
 
 
 def test_clear(cache: KreuzbergCache[str]) -> None:
-    """Test cache clearing."""
-
     cache.set("value1", key="test1")
     cache.set("value2", key="test2")
 
@@ -232,8 +211,6 @@ def test_clear(cache: KreuzbergCache[str]) -> None:
 
 
 def test_cleanup_cache(cache: KreuzbergCache[str]) -> None:
-    """Test cleanup of expired entries."""
-
     cache_path = cache.cache_dir / "expired.msgpack"
     cache_path.write_text("expired content")
 
@@ -249,8 +226,6 @@ def test_cleanup_cache(cache: KreuzbergCache[str]) -> None:
 
 
 def test_cleanup_cache_size_limit(cache: KreuzbergCache[str]) -> None:
-    """Test cleanup respects size limits."""
-
     for i in range(20):
         cache.set(f"value_{i}" * 1000, key=f"test_{i}")
 
@@ -267,15 +242,11 @@ def test_cleanup_cache_size_limit(cache: KreuzbergCache[str]) -> None:
 
 
 def test_cleanup_cache_exception_handling(cache: KreuzbergCache[str]) -> None:
-    """Test cleanup handles exceptions gracefully."""
-
     with patch("pathlib.Path.glob", side_effect=OSError("Permission denied")):
         cache._cleanup_cache()
 
 
 def test_get_serialization_error(cache: KreuzbergCache[str]) -> None:
-    """Test get handles serialization errors gracefully."""
-
     cache_key = cache._get_cache_key(key="test")
     cache_path = cache._get_cache_path(cache_key)
     cache_path.write_bytes(b"corrupted msgpack data")
@@ -287,8 +258,6 @@ def test_get_serialization_error(cache: KreuzbergCache[str]) -> None:
 
 
 def test_set_serialization_error(cache: KreuzbergCache[str]) -> None:
-    """Test set handles serialization errors gracefully."""
-
     unserializable = lambda x: x  # noqa: E731
 
     with patch("kreuzberg._utils._cache.serialize", side_effect=TypeError("Serialize error")):
@@ -296,8 +265,6 @@ def test_set_serialization_error(cache: KreuzbergCache[str]) -> None:
 
 
 def test_is_processing(cache: KreuzbergCache[str]) -> None:
-    """Test processing state tracking."""
-
     assert not cache.is_processing(key="test")
 
     event = cache.mark_processing(key="test")
@@ -310,7 +277,6 @@ def test_is_processing(cache: KreuzbergCache[str]) -> None:
 
 
 def test_mark_processing_duplicate(cache: KreuzbergCache[str]) -> None:
-    """Test marking same key as processing multiple times."""
     event1 = cache.mark_processing(key="test")
     event2 = cache.mark_processing(key="test")
 
@@ -318,14 +284,10 @@ def test_mark_processing_duplicate(cache: KreuzbergCache[str]) -> None:
 
 
 def test_mark_complete_nonexistent(cache: KreuzbergCache[str]) -> None:
-    """Test marking non-existent key as complete."""
-
     cache.mark_complete(key="nonexistent")
 
 
 def test_get_stats(cache: KreuzbergCache[str]) -> None:
-    """Test cache statistics."""
-
     cache.set("value1", key="test1")
     cache.set("value2", key="test2")
 
@@ -342,7 +304,6 @@ def test_get_stats(cache: KreuzbergCache[str]) -> None:
 
 
 def test_get_stats_os_error(cache: KreuzbergCache[str]) -> None:
-    """Test get_stats handles OS errors gracefully."""
     with patch("pathlib.Path.glob", side_effect=OSError("Permission denied")):
         stats = cache.get_stats()
 
@@ -353,7 +314,8 @@ def test_get_stats_os_error(cache: KreuzbergCache[str]) -> None:
 
 
 def test_get_ocr_cache() -> None:
-    """Test OCR cache factory function."""
+    _ocr_cache_ref.clear()
+
     cache = get_ocr_cache()
     assert isinstance(cache, KreuzbergCache)
     assert cache.cache_type == "ocr"
@@ -363,17 +325,15 @@ def test_get_ocr_cache() -> None:
 
 
 def test_get_ocr_cache_with_env_vars() -> None:
-    """Test OCR cache with environment variables."""
-    with (
-        patch.dict(
-            os.environ,
-            {
-                "KREUZBERG_CACHE_DIR": "/tmp/test_cache",
-                "KREUZBERG_OCR_CACHE_SIZE_MB": "100",
-                "KREUZBERG_OCR_CACHE_AGE_DAYS": "7",
-            },
-        ),
-        patch("kreuzberg._utils._cache._ocr_cache", None),
+    _ocr_cache_ref.clear()
+
+    with patch.dict(
+        os.environ,
+        {
+            "KREUZBERG_CACHE_DIR": "/tmp/test_cache",
+            "KREUZBERG_OCR_CACHE_SIZE_MB": "100",
+            "KREUZBERG_OCR_CACHE_AGE_DAYS": "7",
+        },
     ):
         cache = get_ocr_cache()
         assert cache.max_cache_size_mb == 100.0
@@ -381,28 +341,31 @@ def test_get_ocr_cache_with_env_vars() -> None:
 
 
 def test_get_document_cache() -> None:
-    """Test document cache factory function."""
+    _document_cache_ref.clear()
     cache = get_document_cache()
     assert isinstance(cache, KreuzbergCache)
     assert cache.cache_type == "documents"
 
 
 def test_get_table_cache() -> None:
-    """Test table cache factory function."""
+    _table_cache_ref.clear()
     cache = get_table_cache()
     assert isinstance(cache, KreuzbergCache)
     assert cache.cache_type == "tables"
 
 
 def test_get_mime_cache() -> None:
-    """Test MIME cache factory function."""
+    _mime_cache_ref.clear()
     cache = get_mime_cache()
     assert isinstance(cache, KreuzbergCache)
     assert cache.cache_type == "mime"
 
 
 def test_clear_all_caches() -> None:
-    """Test clearing all global caches."""
+    _ocr_cache_ref.clear()
+    _document_cache_ref.clear()
+    _table_cache_ref.clear()
+    _mime_cache_ref.clear()
 
     get_ocr_cache().set(
         ExtractionResult(content="test", mime_type="text/plain", metadata={}, chunks=[], tables=[]), key="test"
@@ -411,13 +374,13 @@ def test_clear_all_caches() -> None:
 
     clear_all_caches()
 
-    assert get_ocr_cache().get(key="test") is None
-    assert get_mime_cache().get(key="test") is None
+    assert not _ocr_cache_ref.is_initialized()
+    assert not _document_cache_ref.is_initialized()
+    assert not _table_cache_ref.is_initialized()
+    assert not _mime_cache_ref.is_initialized()
 
 
 def test_cleanup_cache_periodic_trigger(cache: KreuzbergCache[str]) -> None:
-    """Test periodic cleanup trigger during set operations."""
-
     with patch.object(cache, "_cleanup_cache") as mock_cleanup:
         for i in range(200):
             cache_key = cache._get_cache_key(test_key=f"test_{i}")
@@ -433,8 +396,6 @@ def test_cleanup_cache_periodic_trigger(cache: KreuzbergCache[str]) -> None:
 
 @pytest.mark.anyio
 async def test_async_cleanup_cache_periodic_trigger(cache: KreuzbergCache[str]) -> None:
-    """Test periodic cleanup trigger during async set operations."""
-
     with patch.object(cache, "_cleanup_cache") as mock_cleanup:
         for i in range(200):
             cache_key = cache._get_cache_key(test_key=f"test_{i}")
@@ -450,8 +411,6 @@ async def test_async_cleanup_cache_periodic_trigger(cache: KreuzbergCache[str])
 
 @pytest.mark.anyio
 async def test_aget_serialization_error(cache: KreuzbergCache[str]) -> None:
-    """Test async get handles serialization errors gracefully."""
-
     cache_key = cache._get_cache_key(key="test")
     cache_path = cache._get_cache_path(cache_key)
     cache_path.write_bytes(b"corrupted msgpack data")
@@ -462,8 +421,6 @@ async def test_aget_serialization_error(cache: KreuzbergCache[str]) -> None:
 
 @pytest.mark.anyio
 async def test_aset_serialization_error(cache: KreuzbergCache[str]) -> None:
-    """Test async set handles serialization errors gracefully."""
-
     unserializable = lambda x: x  # noqa: E731
 
     with patch("kreuzberg._utils._cache.serialize", side_effect=TypeError("Serialize error")):
